/*
 *   Copyright (C) 1997, 1998, 1999 Loic Dachary
 *
 *   This program is free software; you can redistribute it and/or modify it
 *   under the terms of the GNU General Public License as published by the
 *   Free Software Foundation; either version 2, or (at your option) any
 *   later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, 675 Mass Ave, Cambridge, MA 02139, USA. 
 *
 */
#ifndef _html_h
#define _html_h

#include <webbase_url.h>

#ifdef __cplusplus
extern "C" {
#endif

int html_href(char* path, webbase_url_t* webbase_url, int size_limit);
int html_content_begin(char* buffer, int buffer_length, webbase_url_t* webbase_url);

#ifdef __cplusplus
}
#endif

#endif /* _html_h */
